# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SatParameters(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    VariableOrderValue = typing___NewType('VariableOrderValue', builtin___int)
    type___VariableOrderValue = VariableOrderValue
    VariableOrder: _VariableOrder
    class _VariableOrder(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.VariableOrderValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        IN_ORDER = typing___cast(SatParameters.VariableOrderValue, 0)
        IN_REVERSE_ORDER = typing___cast(SatParameters.VariableOrderValue, 1)
        IN_RANDOM_ORDER = typing___cast(SatParameters.VariableOrderValue, 2)
    IN_ORDER = typing___cast(SatParameters.VariableOrderValue, 0)
    IN_REVERSE_ORDER = typing___cast(SatParameters.VariableOrderValue, 1)
    IN_RANDOM_ORDER = typing___cast(SatParameters.VariableOrderValue, 2)
    type___VariableOrder = VariableOrder

    PolarityValue = typing___NewType('PolarityValue', builtin___int)
    type___PolarityValue = PolarityValue
    Polarity: _Polarity
    class _Polarity(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.PolarityValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        POLARITY_TRUE = typing___cast(SatParameters.PolarityValue, 0)
        POLARITY_FALSE = typing___cast(SatParameters.PolarityValue, 1)
        POLARITY_RANDOM = typing___cast(SatParameters.PolarityValue, 2)
        POLARITY_WEIGHTED_SIGN = typing___cast(SatParameters.PolarityValue, 3)
        POLARITY_REVERSE_WEIGHTED_SIGN = typing___cast(SatParameters.PolarityValue, 4)
    POLARITY_TRUE = typing___cast(SatParameters.PolarityValue, 0)
    POLARITY_FALSE = typing___cast(SatParameters.PolarityValue, 1)
    POLARITY_RANDOM = typing___cast(SatParameters.PolarityValue, 2)
    POLARITY_WEIGHTED_SIGN = typing___cast(SatParameters.PolarityValue, 3)
    POLARITY_REVERSE_WEIGHTED_SIGN = typing___cast(SatParameters.PolarityValue, 4)
    type___Polarity = Polarity

    ConflictMinimizationAlgorithmValue = typing___NewType('ConflictMinimizationAlgorithmValue', builtin___int)
    type___ConflictMinimizationAlgorithmValue = ConflictMinimizationAlgorithmValue
    ConflictMinimizationAlgorithm: _ConflictMinimizationAlgorithm
    class _ConflictMinimizationAlgorithm(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.ConflictMinimizationAlgorithmValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        NONE = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 0)
        SIMPLE = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 1)
        RECURSIVE = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 2)
        EXPERIMENTAL = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 3)
    NONE = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 0)
    SIMPLE = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 1)
    RECURSIVE = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 2)
    EXPERIMENTAL = typing___cast(SatParameters.ConflictMinimizationAlgorithmValue, 3)
    type___ConflictMinimizationAlgorithm = ConflictMinimizationAlgorithm

    BinaryMinizationAlgorithmValue = typing___NewType('BinaryMinizationAlgorithmValue', builtin___int)
    type___BinaryMinizationAlgorithmValue = BinaryMinizationAlgorithmValue
    BinaryMinizationAlgorithm: _BinaryMinizationAlgorithm
    class _BinaryMinizationAlgorithm(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.BinaryMinizationAlgorithmValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        NO_BINARY_MINIMIZATION = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 0)
        BINARY_MINIMIZATION_FIRST = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 1)
        BINARY_MINIMIZATION_FIRST_WITH_TRANSITIVE_REDUCTION = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 4)
        BINARY_MINIMIZATION_WITH_REACHABILITY = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 2)
        EXPERIMENTAL_BINARY_MINIMIZATION = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 3)
    NO_BINARY_MINIMIZATION = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 0)
    BINARY_MINIMIZATION_FIRST = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 1)
    BINARY_MINIMIZATION_FIRST_WITH_TRANSITIVE_REDUCTION = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 4)
    BINARY_MINIMIZATION_WITH_REACHABILITY = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 2)
    EXPERIMENTAL_BINARY_MINIMIZATION = typing___cast(SatParameters.BinaryMinizationAlgorithmValue, 3)
    type___BinaryMinizationAlgorithm = BinaryMinizationAlgorithm

    ClauseProtectionValue = typing___NewType('ClauseProtectionValue', builtin___int)
    type___ClauseProtectionValue = ClauseProtectionValue
    ClauseProtection: _ClauseProtection
    class _ClauseProtection(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.ClauseProtectionValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        PROTECTION_NONE = typing___cast(SatParameters.ClauseProtectionValue, 0)
        PROTECTION_ALWAYS = typing___cast(SatParameters.ClauseProtectionValue, 1)
        PROTECTION_LBD = typing___cast(SatParameters.ClauseProtectionValue, 2)
    PROTECTION_NONE = typing___cast(SatParameters.ClauseProtectionValue, 0)
    PROTECTION_ALWAYS = typing___cast(SatParameters.ClauseProtectionValue, 1)
    PROTECTION_LBD = typing___cast(SatParameters.ClauseProtectionValue, 2)
    type___ClauseProtection = ClauseProtection

    ClauseOrderingValue = typing___NewType('ClauseOrderingValue', builtin___int)
    type___ClauseOrderingValue = ClauseOrderingValue
    ClauseOrdering: _ClauseOrdering
    class _ClauseOrdering(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.ClauseOrderingValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        CLAUSE_ACTIVITY = typing___cast(SatParameters.ClauseOrderingValue, 0)
        CLAUSE_LBD = typing___cast(SatParameters.ClauseOrderingValue, 1)
    CLAUSE_ACTIVITY = typing___cast(SatParameters.ClauseOrderingValue, 0)
    CLAUSE_LBD = typing___cast(SatParameters.ClauseOrderingValue, 1)
    type___ClauseOrdering = ClauseOrdering

    RestartAlgorithmValue = typing___NewType('RestartAlgorithmValue', builtin___int)
    type___RestartAlgorithmValue = RestartAlgorithmValue
    RestartAlgorithm: _RestartAlgorithm
    class _RestartAlgorithm(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.RestartAlgorithmValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        NO_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 0)
        LUBY_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 1)
        DL_MOVING_AVERAGE_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 2)
        LBD_MOVING_AVERAGE_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 3)
        FIXED_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 4)
    NO_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 0)
    LUBY_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 1)
    DL_MOVING_AVERAGE_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 2)
    LBD_MOVING_AVERAGE_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 3)
    FIXED_RESTART = typing___cast(SatParameters.RestartAlgorithmValue, 4)
    type___RestartAlgorithm = RestartAlgorithm

    MaxSatAssumptionOrderValue = typing___NewType('MaxSatAssumptionOrderValue', builtin___int)
    type___MaxSatAssumptionOrderValue = MaxSatAssumptionOrderValue
    MaxSatAssumptionOrder: _MaxSatAssumptionOrder
    class _MaxSatAssumptionOrder(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.MaxSatAssumptionOrderValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        DEFAULT_ASSUMPTION_ORDER = typing___cast(SatParameters.MaxSatAssumptionOrderValue, 0)
        ORDER_ASSUMPTION_BY_DEPTH = typing___cast(SatParameters.MaxSatAssumptionOrderValue, 1)
        ORDER_ASSUMPTION_BY_WEIGHT = typing___cast(SatParameters.MaxSatAssumptionOrderValue, 2)
    DEFAULT_ASSUMPTION_ORDER = typing___cast(SatParameters.MaxSatAssumptionOrderValue, 0)
    ORDER_ASSUMPTION_BY_DEPTH = typing___cast(SatParameters.MaxSatAssumptionOrderValue, 1)
    ORDER_ASSUMPTION_BY_WEIGHT = typing___cast(SatParameters.MaxSatAssumptionOrderValue, 2)
    type___MaxSatAssumptionOrder = MaxSatAssumptionOrder

    MaxSatStratificationAlgorithmValue = typing___NewType('MaxSatStratificationAlgorithmValue', builtin___int)
    type___MaxSatStratificationAlgorithmValue = MaxSatStratificationAlgorithmValue
    MaxSatStratificationAlgorithm: _MaxSatStratificationAlgorithm
    class _MaxSatStratificationAlgorithm(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.MaxSatStratificationAlgorithmValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        STRATIFICATION_NONE = typing___cast(SatParameters.MaxSatStratificationAlgorithmValue, 0)
        STRATIFICATION_DESCENT = typing___cast(SatParameters.MaxSatStratificationAlgorithmValue, 1)
        STRATIFICATION_ASCENT = typing___cast(SatParameters.MaxSatStratificationAlgorithmValue, 2)
    STRATIFICATION_NONE = typing___cast(SatParameters.MaxSatStratificationAlgorithmValue, 0)
    STRATIFICATION_DESCENT = typing___cast(SatParameters.MaxSatStratificationAlgorithmValue, 1)
    STRATIFICATION_ASCENT = typing___cast(SatParameters.MaxSatStratificationAlgorithmValue, 2)
    type___MaxSatStratificationAlgorithm = MaxSatStratificationAlgorithm

    SearchBranchingValue = typing___NewType('SearchBranchingValue', builtin___int)
    type___SearchBranchingValue = SearchBranchingValue
    SearchBranching: _SearchBranching
    class _SearchBranching(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.SearchBranchingValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        AUTOMATIC_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 0)
        FIXED_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 1)
        PORTFOLIO_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 2)
        LP_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 3)
        PSEUDO_COST_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 4)
        PORTFOLIO_WITH_QUICK_RESTART_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 5)
        HINT_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 6)
    AUTOMATIC_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 0)
    FIXED_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 1)
    PORTFOLIO_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 2)
    LP_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 3)
    PSEUDO_COST_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 4)
    PORTFOLIO_WITH_QUICK_RESTART_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 5)
    HINT_SEARCH = typing___cast(SatParameters.SearchBranchingValue, 6)
    type___SearchBranching = SearchBranching

    FPRoundingMethodValue = typing___NewType('FPRoundingMethodValue', builtin___int)
    type___FPRoundingMethodValue = FPRoundingMethodValue
    FPRoundingMethod: _FPRoundingMethod
    class _FPRoundingMethod(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[SatParameters.FPRoundingMethodValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        NEAREST_INTEGER = typing___cast(SatParameters.FPRoundingMethodValue, 0)
        LOCK_BASED = typing___cast(SatParameters.FPRoundingMethodValue, 1)
    NEAREST_INTEGER = typing___cast(SatParameters.FPRoundingMethodValue, 0)
    LOCK_BASED = typing___cast(SatParameters.FPRoundingMethodValue, 1)
    type___FPRoundingMethod = FPRoundingMethod

    preferred_variable_order: type___SatParameters.VariableOrderValue = ...
    initial_polarity: type___SatParameters.PolarityValue = ...
    use_phase_saving: builtin___bool = ...
    random_polarity_ratio: builtin___float = ...
    random_branches_ratio: builtin___float = ...
    use_erwa_heuristic: builtin___bool = ...
    initial_variables_activity: builtin___float = ...
    also_bump_variables_in_conflict_reasons: builtin___bool = ...
    minimization_algorithm: type___SatParameters.ConflictMinimizationAlgorithmValue = ...
    binary_minimization_algorithm: type___SatParameters.BinaryMinizationAlgorithmValue = ...
    subsumption_during_conflict_analysis: builtin___bool = ...
    clause_cleanup_period: builtin___int = ...
    clause_cleanup_target: builtin___int = ...
    clause_cleanup_protection: type___SatParameters.ClauseProtectionValue = ...
    clause_cleanup_lbd_bound: builtin___int = ...
    clause_cleanup_ordering: type___SatParameters.ClauseOrderingValue = ...
    pb_cleanup_increment: builtin___int = ...
    pb_cleanup_ratio: builtin___float = ...
    minimize_with_propagation_restart_period: builtin___int = ...
    minimize_with_propagation_num_decisions: builtin___int = ...
    variable_activity_decay: builtin___float = ...
    max_variable_activity_value: builtin___float = ...
    glucose_max_decay: builtin___float = ...
    glucose_decay_increment: builtin___float = ...
    glucose_decay_increment_period: builtin___int = ...
    clause_activity_decay: builtin___float = ...
    max_clause_activity_value: builtin___float = ...
    restart_algorithms: google___protobuf___internal___containers___RepeatedScalarFieldContainer[type___SatParameters.RestartAlgorithmValue] = ...
    default_restart_algorithms: typing___Text = ...
    restart_period: builtin___int = ...
    restart_running_window_size: builtin___int = ...
    restart_dl_average_ratio: builtin___float = ...
    restart_lbd_average_ratio: builtin___float = ...
    use_blocking_restart: builtin___bool = ...
    blocking_restart_window_size: builtin___int = ...
    blocking_restart_multiplier: builtin___float = ...
    num_conflicts_before_strategy_changes: builtin___int = ...
    strategy_change_increase_ratio: builtin___float = ...
    max_time_in_seconds: builtin___float = ...
    max_deterministic_time: builtin___float = ...
    max_number_of_conflicts: builtin___int = ...
    max_memory_in_mb: builtin___int = ...
    absolute_gap_limit: builtin___float = ...
    relative_gap_limit: builtin___float = ...
    treat_binary_clauses_separately: builtin___bool = ...
    random_seed: builtin___int = ...
    log_search_progress: builtin___bool = ...
    use_pb_resolution: builtin___bool = ...
    minimize_reduction_during_pb_resolution: builtin___bool = ...
    count_assumption_levels_in_lbd: builtin___bool = ...
    presolve_bve_threshold: builtin___int = ...
    presolve_bve_clause_weight: builtin___int = ...
    presolve_probing_deterministic_time_limit: builtin___float = ...
    presolve_blocked_clause: builtin___bool = ...
    presolve_use_bva: builtin___bool = ...
    presolve_bva_threshold: builtin___int = ...
    max_presolve_iterations: builtin___int = ...
    cp_model_presolve: builtin___bool = ...
    cp_model_postsolve_with_full_solver: builtin___bool = ...
    cp_model_max_num_presolve_operations: builtin___int = ...
    cp_model_probing_level: builtin___int = ...
    cp_model_use_sat_presolve: builtin___bool = ...
    use_sat_inprocessing: builtin___bool = ...
    expand_element_constraints: builtin___bool = ...
    expand_automaton_constraints: builtin___bool = ...
    expand_table_constraints: builtin___bool = ...
    merge_no_overlap_work_limit: builtin___float = ...
    merge_at_most_one_work_limit: builtin___float = ...
    presolve_substitution_level: builtin___int = ...
    use_optimization_hints: builtin___bool = ...
    minimize_core: builtin___bool = ...
    find_multiple_cores: builtin___bool = ...
    cover_optimization: builtin___bool = ...
    max_sat_assumption_order: type___SatParameters.MaxSatAssumptionOrderValue = ...
    max_sat_reverse_assumption_order: builtin___bool = ...
    max_sat_stratification: type___SatParameters.MaxSatStratificationAlgorithmValue = ...
    use_precedences_in_disjunctive_constraint: builtin___bool = ...
    use_overload_checker_in_cumulative_constraint: builtin___bool = ...
    use_timetable_edge_finding_in_cumulative_constraint: builtin___bool = ...
    use_disjunctive_constraint_in_cumulative_constraint: builtin___bool = ...
    linearization_level: builtin___int = ...
    boolean_encoding_level: builtin___int = ...
    max_num_cuts: builtin___int = ...
    only_add_cuts_at_level_zero: builtin___bool = ...
    add_knapsack_cuts: builtin___bool = ...
    add_cg_cuts: builtin___bool = ...
    add_mir_cuts: builtin___bool = ...
    max_all_diff_cut_size: builtin___int = ...
    add_lin_max_cuts: builtin___bool = ...
    max_integer_rounding_scaling: builtin___int = ...
    add_lp_constraints_lazily: builtin___bool = ...
    min_orthogonality_for_lp_constraints: builtin___float = ...
    max_cut_rounds_at_level_zero: builtin___int = ...
    max_consecutive_inactive_count: builtin___int = ...
    cut_max_active_count_value: builtin___float = ...
    cut_active_count_decay: builtin___float = ...
    cut_cleanup_target: builtin___int = ...
    new_constraints_batch_size: builtin___int = ...
    search_branching: type___SatParameters.SearchBranchingValue = ...
    hint_conflict_limit: builtin___int = ...
    exploit_integer_lp_solution: builtin___bool = ...
    exploit_all_lp_solution: builtin___bool = ...
    exploit_best_solution: builtin___bool = ...
    exploit_relaxation_solution: builtin___bool = ...
    exploit_objective: builtin___bool = ...
    probing_period_at_root: builtin___int = ...
    pseudo_cost_reliability_threshold: builtin___int = ...
    optimize_with_core: builtin___bool = ...
    binary_search_num_conflicts: builtin___int = ...
    optimize_with_max_hs: builtin___bool = ...
    enumerate_all_solutions: builtin___bool = ...
    fill_tightened_domains_in_response: builtin___bool = ...
    instantiate_all_variables: builtin___bool = ...
    auto_detect_greater_than_at_least_one_of: builtin___bool = ...
    stop_after_first_solution: builtin___bool = ...
    stop_after_presolve: builtin___bool = ...
    num_search_workers: builtin___int = ...
    interleave_search: builtin___bool = ...
    interleave_batch_size: builtin___int = ...
    reduce_memory_usage_in_interleave_mode: builtin___bool = ...
    share_objective_bounds: builtin___bool = ...
    share_level_zero_bounds: builtin___bool = ...
    use_lns_only: builtin___bool = ...
    lns_focus_on_decision_variables: builtin___bool = ...
    use_rins_lns: builtin___bool = ...
    use_feasibility_pump: builtin___bool = ...
    fp_rounding: type___SatParameters.FPRoundingMethodValue = ...
    use_relaxation_lns: builtin___bool = ...
    diversify_lns_params: builtin___bool = ...
    randomize_search: builtin___bool = ...
    search_randomization_tolerance: builtin___int = ...
    use_optional_variables: builtin___bool = ...
    use_exact_lp_reason: builtin___bool = ...
    use_branching_in_lp: builtin___bool = ...
    use_combined_no_overlap: builtin___bool = ...
    catch_sigint_signal: builtin___bool = ...
    use_implied_bounds: builtin___bool = ...
    mip_max_bound: builtin___float = ...
    mip_var_scaling: builtin___float = ...
    mip_wanted_precision: builtin___float = ...
    mip_max_activity_exponent: builtin___int = ...
    mip_check_precision: builtin___float = ...

    def __init__(self,
        *,
        preferred_variable_order : typing___Optional[type___SatParameters.VariableOrderValue] = None,
        initial_polarity : typing___Optional[type___SatParameters.PolarityValue] = None,
        use_phase_saving : typing___Optional[builtin___bool] = None,
        random_polarity_ratio : typing___Optional[builtin___float] = None,
        random_branches_ratio : typing___Optional[builtin___float] = None,
        use_erwa_heuristic : typing___Optional[builtin___bool] = None,
        initial_variables_activity : typing___Optional[builtin___float] = None,
        also_bump_variables_in_conflict_reasons : typing___Optional[builtin___bool] = None,
        minimization_algorithm : typing___Optional[type___SatParameters.ConflictMinimizationAlgorithmValue] = None,
        binary_minimization_algorithm : typing___Optional[type___SatParameters.BinaryMinizationAlgorithmValue] = None,
        subsumption_during_conflict_analysis : typing___Optional[builtin___bool] = None,
        clause_cleanup_period : typing___Optional[builtin___int] = None,
        clause_cleanup_target : typing___Optional[builtin___int] = None,
        clause_cleanup_protection : typing___Optional[type___SatParameters.ClauseProtectionValue] = None,
        clause_cleanup_lbd_bound : typing___Optional[builtin___int] = None,
        clause_cleanup_ordering : typing___Optional[type___SatParameters.ClauseOrderingValue] = None,
        pb_cleanup_increment : typing___Optional[builtin___int] = None,
        pb_cleanup_ratio : typing___Optional[builtin___float] = None,
        minimize_with_propagation_restart_period : typing___Optional[builtin___int] = None,
        minimize_with_propagation_num_decisions : typing___Optional[builtin___int] = None,
        variable_activity_decay : typing___Optional[builtin___float] = None,
        max_variable_activity_value : typing___Optional[builtin___float] = None,
        glucose_max_decay : typing___Optional[builtin___float] = None,
        glucose_decay_increment : typing___Optional[builtin___float] = None,
        glucose_decay_increment_period : typing___Optional[builtin___int] = None,
        clause_activity_decay : typing___Optional[builtin___float] = None,
        max_clause_activity_value : typing___Optional[builtin___float] = None,
        restart_algorithms : typing___Optional[typing___Iterable[type___SatParameters.RestartAlgorithmValue]] = None,
        default_restart_algorithms : typing___Optional[typing___Text] = None,
        restart_period : typing___Optional[builtin___int] = None,
        restart_running_window_size : typing___Optional[builtin___int] = None,
        restart_dl_average_ratio : typing___Optional[builtin___float] = None,
        restart_lbd_average_ratio : typing___Optional[builtin___float] = None,
        use_blocking_restart : typing___Optional[builtin___bool] = None,
        blocking_restart_window_size : typing___Optional[builtin___int] = None,
        blocking_restart_multiplier : typing___Optional[builtin___float] = None,
        num_conflicts_before_strategy_changes : typing___Optional[builtin___int] = None,
        strategy_change_increase_ratio : typing___Optional[builtin___float] = None,
        max_time_in_seconds : typing___Optional[builtin___float] = None,
        max_deterministic_time : typing___Optional[builtin___float] = None,
        max_number_of_conflicts : typing___Optional[builtin___int] = None,
        max_memory_in_mb : typing___Optional[builtin___int] = None,
        absolute_gap_limit : typing___Optional[builtin___float] = None,
        relative_gap_limit : typing___Optional[builtin___float] = None,
        treat_binary_clauses_separately : typing___Optional[builtin___bool] = None,
        random_seed : typing___Optional[builtin___int] = None,
        log_search_progress : typing___Optional[builtin___bool] = None,
        use_pb_resolution : typing___Optional[builtin___bool] = None,
        minimize_reduction_during_pb_resolution : typing___Optional[builtin___bool] = None,
        count_assumption_levels_in_lbd : typing___Optional[builtin___bool] = None,
        presolve_bve_threshold : typing___Optional[builtin___int] = None,
        presolve_bve_clause_weight : typing___Optional[builtin___int] = None,
        presolve_probing_deterministic_time_limit : typing___Optional[builtin___float] = None,
        presolve_blocked_clause : typing___Optional[builtin___bool] = None,
        presolve_use_bva : typing___Optional[builtin___bool] = None,
        presolve_bva_threshold : typing___Optional[builtin___int] = None,
        max_presolve_iterations : typing___Optional[builtin___int] = None,
        cp_model_presolve : typing___Optional[builtin___bool] = None,
        cp_model_postsolve_with_full_solver : typing___Optional[builtin___bool] = None,
        cp_model_max_num_presolve_operations : typing___Optional[builtin___int] = None,
        cp_model_probing_level : typing___Optional[builtin___int] = None,
        cp_model_use_sat_presolve : typing___Optional[builtin___bool] = None,
        use_sat_inprocessing : typing___Optional[builtin___bool] = None,
        expand_element_constraints : typing___Optional[builtin___bool] = None,
        expand_automaton_constraints : typing___Optional[builtin___bool] = None,
        expand_table_constraints : typing___Optional[builtin___bool] = None,
        merge_no_overlap_work_limit : typing___Optional[builtin___float] = None,
        merge_at_most_one_work_limit : typing___Optional[builtin___float] = None,
        presolve_substitution_level : typing___Optional[builtin___int] = None,
        use_optimization_hints : typing___Optional[builtin___bool] = None,
        minimize_core : typing___Optional[builtin___bool] = None,
        find_multiple_cores : typing___Optional[builtin___bool] = None,
        cover_optimization : typing___Optional[builtin___bool] = None,
        max_sat_assumption_order : typing___Optional[type___SatParameters.MaxSatAssumptionOrderValue] = None,
        max_sat_reverse_assumption_order : typing___Optional[builtin___bool] = None,
        max_sat_stratification : typing___Optional[type___SatParameters.MaxSatStratificationAlgorithmValue] = None,
        use_precedences_in_disjunctive_constraint : typing___Optional[builtin___bool] = None,
        use_overload_checker_in_cumulative_constraint : typing___Optional[builtin___bool] = None,
        use_timetable_edge_finding_in_cumulative_constraint : typing___Optional[builtin___bool] = None,
        use_disjunctive_constraint_in_cumulative_constraint : typing___Optional[builtin___bool] = None,
        linearization_level : typing___Optional[builtin___int] = None,
        boolean_encoding_level : typing___Optional[builtin___int] = None,
        max_num_cuts : typing___Optional[builtin___int] = None,
        only_add_cuts_at_level_zero : typing___Optional[builtin___bool] = None,
        add_knapsack_cuts : typing___Optional[builtin___bool] = None,
        add_cg_cuts : typing___Optional[builtin___bool] = None,
        add_mir_cuts : typing___Optional[builtin___bool] = None,
        max_all_diff_cut_size : typing___Optional[builtin___int] = None,
        add_lin_max_cuts : typing___Optional[builtin___bool] = None,
        max_integer_rounding_scaling : typing___Optional[builtin___int] = None,
        add_lp_constraints_lazily : typing___Optional[builtin___bool] = None,
        min_orthogonality_for_lp_constraints : typing___Optional[builtin___float] = None,
        max_cut_rounds_at_level_zero : typing___Optional[builtin___int] = None,
        max_consecutive_inactive_count : typing___Optional[builtin___int] = None,
        cut_max_active_count_value : typing___Optional[builtin___float] = None,
        cut_active_count_decay : typing___Optional[builtin___float] = None,
        cut_cleanup_target : typing___Optional[builtin___int] = None,
        new_constraints_batch_size : typing___Optional[builtin___int] = None,
        search_branching : typing___Optional[type___SatParameters.SearchBranchingValue] = None,
        hint_conflict_limit : typing___Optional[builtin___int] = None,
        exploit_integer_lp_solution : typing___Optional[builtin___bool] = None,
        exploit_all_lp_solution : typing___Optional[builtin___bool] = None,
        exploit_best_solution : typing___Optional[builtin___bool] = None,
        exploit_relaxation_solution : typing___Optional[builtin___bool] = None,
        exploit_objective : typing___Optional[builtin___bool] = None,
        probing_period_at_root : typing___Optional[builtin___int] = None,
        pseudo_cost_reliability_threshold : typing___Optional[builtin___int] = None,
        optimize_with_core : typing___Optional[builtin___bool] = None,
        binary_search_num_conflicts : typing___Optional[builtin___int] = None,
        optimize_with_max_hs : typing___Optional[builtin___bool] = None,
        enumerate_all_solutions : typing___Optional[builtin___bool] = None,
        fill_tightened_domains_in_response : typing___Optional[builtin___bool] = None,
        instantiate_all_variables : typing___Optional[builtin___bool] = None,
        auto_detect_greater_than_at_least_one_of : typing___Optional[builtin___bool] = None,
        stop_after_first_solution : typing___Optional[builtin___bool] = None,
        stop_after_presolve : typing___Optional[builtin___bool] = None,
        num_search_workers : typing___Optional[builtin___int] = None,
        interleave_search : typing___Optional[builtin___bool] = None,
        interleave_batch_size : typing___Optional[builtin___int] = None,
        reduce_memory_usage_in_interleave_mode : typing___Optional[builtin___bool] = None,
        share_objective_bounds : typing___Optional[builtin___bool] = None,
        share_level_zero_bounds : typing___Optional[builtin___bool] = None,
        use_lns_only : typing___Optional[builtin___bool] = None,
        lns_focus_on_decision_variables : typing___Optional[builtin___bool] = None,
        use_rins_lns : typing___Optional[builtin___bool] = None,
        use_feasibility_pump : typing___Optional[builtin___bool] = None,
        fp_rounding : typing___Optional[type___SatParameters.FPRoundingMethodValue] = None,
        use_relaxation_lns : typing___Optional[builtin___bool] = None,
        diversify_lns_params : typing___Optional[builtin___bool] = None,
        randomize_search : typing___Optional[builtin___bool] = None,
        search_randomization_tolerance : typing___Optional[builtin___int] = None,
        use_optional_variables : typing___Optional[builtin___bool] = None,
        use_exact_lp_reason : typing___Optional[builtin___bool] = None,
        use_branching_in_lp : typing___Optional[builtin___bool] = None,
        use_combined_no_overlap : typing___Optional[builtin___bool] = None,
        catch_sigint_signal : typing___Optional[builtin___bool] = None,
        use_implied_bounds : typing___Optional[builtin___bool] = None,
        mip_max_bound : typing___Optional[builtin___float] = None,
        mip_var_scaling : typing___Optional[builtin___float] = None,
        mip_wanted_precision : typing___Optional[builtin___float] = None,
        mip_max_activity_exponent : typing___Optional[builtin___int] = None,
        mip_check_precision : typing___Optional[builtin___float] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SatParameters: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SatParameters: ...
    def HasField(self, field_name: typing_extensions___Literal[u"absolute_gap_limit",b"absolute_gap_limit",u"add_cg_cuts",b"add_cg_cuts",u"add_knapsack_cuts",b"add_knapsack_cuts",u"add_lin_max_cuts",b"add_lin_max_cuts",u"add_lp_constraints_lazily",b"add_lp_constraints_lazily",u"add_mir_cuts",b"add_mir_cuts",u"also_bump_variables_in_conflict_reasons",b"also_bump_variables_in_conflict_reasons",u"auto_detect_greater_than_at_least_one_of",b"auto_detect_greater_than_at_least_one_of",u"binary_minimization_algorithm",b"binary_minimization_algorithm",u"binary_search_num_conflicts",b"binary_search_num_conflicts",u"blocking_restart_multiplier",b"blocking_restart_multiplier",u"blocking_restart_window_size",b"blocking_restart_window_size",u"boolean_encoding_level",b"boolean_encoding_level",u"catch_sigint_signal",b"catch_sigint_signal",u"clause_activity_decay",b"clause_activity_decay",u"clause_cleanup_lbd_bound",b"clause_cleanup_lbd_bound",u"clause_cleanup_ordering",b"clause_cleanup_ordering",u"clause_cleanup_period",b"clause_cleanup_period",u"clause_cleanup_protection",b"clause_cleanup_protection",u"clause_cleanup_target",b"clause_cleanup_target",u"count_assumption_levels_in_lbd",b"count_assumption_levels_in_lbd",u"cover_optimization",b"cover_optimization",u"cp_model_max_num_presolve_operations",b"cp_model_max_num_presolve_operations",u"cp_model_postsolve_with_full_solver",b"cp_model_postsolve_with_full_solver",u"cp_model_presolve",b"cp_model_presolve",u"cp_model_probing_level",b"cp_model_probing_level",u"cp_model_use_sat_presolve",b"cp_model_use_sat_presolve",u"cut_active_count_decay",b"cut_active_count_decay",u"cut_cleanup_target",b"cut_cleanup_target",u"cut_max_active_count_value",b"cut_max_active_count_value",u"default_restart_algorithms",b"default_restart_algorithms",u"diversify_lns_params",b"diversify_lns_params",u"enumerate_all_solutions",b"enumerate_all_solutions",u"expand_automaton_constraints",b"expand_automaton_constraints",u"expand_element_constraints",b"expand_element_constraints",u"expand_table_constraints",b"expand_table_constraints",u"exploit_all_lp_solution",b"exploit_all_lp_solution",u"exploit_best_solution",b"exploit_best_solution",u"exploit_integer_lp_solution",b"exploit_integer_lp_solution",u"exploit_objective",b"exploit_objective",u"exploit_relaxation_solution",b"exploit_relaxation_solution",u"fill_tightened_domains_in_response",b"fill_tightened_domains_in_response",u"find_multiple_cores",b"find_multiple_cores",u"fp_rounding",b"fp_rounding",u"glucose_decay_increment",b"glucose_decay_increment",u"glucose_decay_increment_period",b"glucose_decay_increment_period",u"glucose_max_decay",b"glucose_max_decay",u"hint_conflict_limit",b"hint_conflict_limit",u"initial_polarity",b"initial_polarity",u"initial_variables_activity",b"initial_variables_activity",u"instantiate_all_variables",b"instantiate_all_variables",u"interleave_batch_size",b"interleave_batch_size",u"interleave_search",b"interleave_search",u"linearization_level",b"linearization_level",u"lns_focus_on_decision_variables",b"lns_focus_on_decision_variables",u"log_search_progress",b"log_search_progress",u"max_all_diff_cut_size",b"max_all_diff_cut_size",u"max_clause_activity_value",b"max_clause_activity_value",u"max_consecutive_inactive_count",b"max_consecutive_inactive_count",u"max_cut_rounds_at_level_zero",b"max_cut_rounds_at_level_zero",u"max_deterministic_time",b"max_deterministic_time",u"max_integer_rounding_scaling",b"max_integer_rounding_scaling",u"max_memory_in_mb",b"max_memory_in_mb",u"max_num_cuts",b"max_num_cuts",u"max_number_of_conflicts",b"max_number_of_conflicts",u"max_presolve_iterations",b"max_presolve_iterations",u"max_sat_assumption_order",b"max_sat_assumption_order",u"max_sat_reverse_assumption_order",b"max_sat_reverse_assumption_order",u"max_sat_stratification",b"max_sat_stratification",u"max_time_in_seconds",b"max_time_in_seconds",u"max_variable_activity_value",b"max_variable_activity_value",u"merge_at_most_one_work_limit",b"merge_at_most_one_work_limit",u"merge_no_overlap_work_limit",b"merge_no_overlap_work_limit",u"min_orthogonality_for_lp_constraints",b"min_orthogonality_for_lp_constraints",u"minimization_algorithm",b"minimization_algorithm",u"minimize_core",b"minimize_core",u"minimize_reduction_during_pb_resolution",b"minimize_reduction_during_pb_resolution",u"minimize_with_propagation_num_decisions",b"minimize_with_propagation_num_decisions",u"minimize_with_propagation_restart_period",b"minimize_with_propagation_restart_period",u"mip_check_precision",b"mip_check_precision",u"mip_max_activity_exponent",b"mip_max_activity_exponent",u"mip_max_bound",b"mip_max_bound",u"mip_var_scaling",b"mip_var_scaling",u"mip_wanted_precision",b"mip_wanted_precision",u"new_constraints_batch_size",b"new_constraints_batch_size",u"num_conflicts_before_strategy_changes",b"num_conflicts_before_strategy_changes",u"num_search_workers",b"num_search_workers",u"only_add_cuts_at_level_zero",b"only_add_cuts_at_level_zero",u"optimize_with_core",b"optimize_with_core",u"optimize_with_max_hs",b"optimize_with_max_hs",u"pb_cleanup_increment",b"pb_cleanup_increment",u"pb_cleanup_ratio",b"pb_cleanup_ratio",u"preferred_variable_order",b"preferred_variable_order",u"presolve_blocked_clause",b"presolve_blocked_clause",u"presolve_bva_threshold",b"presolve_bva_threshold",u"presolve_bve_clause_weight",b"presolve_bve_clause_weight",u"presolve_bve_threshold",b"presolve_bve_threshold",u"presolve_probing_deterministic_time_limit",b"presolve_probing_deterministic_time_limit",u"presolve_substitution_level",b"presolve_substitution_level",u"presolve_use_bva",b"presolve_use_bva",u"probing_period_at_root",b"probing_period_at_root",u"pseudo_cost_reliability_threshold",b"pseudo_cost_reliability_threshold",u"random_branches_ratio",b"random_branches_ratio",u"random_polarity_ratio",b"random_polarity_ratio",u"random_seed",b"random_seed",u"randomize_search",b"randomize_search",u"reduce_memory_usage_in_interleave_mode",b"reduce_memory_usage_in_interleave_mode",u"relative_gap_limit",b"relative_gap_limit",u"restart_dl_average_ratio",b"restart_dl_average_ratio",u"restart_lbd_average_ratio",b"restart_lbd_average_ratio",u"restart_period",b"restart_period",u"restart_running_window_size",b"restart_running_window_size",u"search_branching",b"search_branching",u"search_randomization_tolerance",b"search_randomization_tolerance",u"share_level_zero_bounds",b"share_level_zero_bounds",u"share_objective_bounds",b"share_objective_bounds",u"stop_after_first_solution",b"stop_after_first_solution",u"stop_after_presolve",b"stop_after_presolve",u"strategy_change_increase_ratio",b"strategy_change_increase_ratio",u"subsumption_during_conflict_analysis",b"subsumption_during_conflict_analysis",u"treat_binary_clauses_separately",b"treat_binary_clauses_separately",u"use_blocking_restart",b"use_blocking_restart",u"use_branching_in_lp",b"use_branching_in_lp",u"use_combined_no_overlap",b"use_combined_no_overlap",u"use_disjunctive_constraint_in_cumulative_constraint",b"use_disjunctive_constraint_in_cumulative_constraint",u"use_erwa_heuristic",b"use_erwa_heuristic",u"use_exact_lp_reason",b"use_exact_lp_reason",u"use_feasibility_pump",b"use_feasibility_pump",u"use_implied_bounds",b"use_implied_bounds",u"use_lns_only",b"use_lns_only",u"use_optimization_hints",b"use_optimization_hints",u"use_optional_variables",b"use_optional_variables",u"use_overload_checker_in_cumulative_constraint",b"use_overload_checker_in_cumulative_constraint",u"use_pb_resolution",b"use_pb_resolution",u"use_phase_saving",b"use_phase_saving",u"use_precedences_in_disjunctive_constraint",b"use_precedences_in_disjunctive_constraint",u"use_relaxation_lns",b"use_relaxation_lns",u"use_rins_lns",b"use_rins_lns",u"use_sat_inprocessing",b"use_sat_inprocessing",u"use_timetable_edge_finding_in_cumulative_constraint",b"use_timetable_edge_finding_in_cumulative_constraint",u"variable_activity_decay",b"variable_activity_decay"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"absolute_gap_limit",b"absolute_gap_limit",u"add_cg_cuts",b"add_cg_cuts",u"add_knapsack_cuts",b"add_knapsack_cuts",u"add_lin_max_cuts",b"add_lin_max_cuts",u"add_lp_constraints_lazily",b"add_lp_constraints_lazily",u"add_mir_cuts",b"add_mir_cuts",u"also_bump_variables_in_conflict_reasons",b"also_bump_variables_in_conflict_reasons",u"auto_detect_greater_than_at_least_one_of",b"auto_detect_greater_than_at_least_one_of",u"binary_minimization_algorithm",b"binary_minimization_algorithm",u"binary_search_num_conflicts",b"binary_search_num_conflicts",u"blocking_restart_multiplier",b"blocking_restart_multiplier",u"blocking_restart_window_size",b"blocking_restart_window_size",u"boolean_encoding_level",b"boolean_encoding_level",u"catch_sigint_signal",b"catch_sigint_signal",u"clause_activity_decay",b"clause_activity_decay",u"clause_cleanup_lbd_bound",b"clause_cleanup_lbd_bound",u"clause_cleanup_ordering",b"clause_cleanup_ordering",u"clause_cleanup_period",b"clause_cleanup_period",u"clause_cleanup_protection",b"clause_cleanup_protection",u"clause_cleanup_target",b"clause_cleanup_target",u"count_assumption_levels_in_lbd",b"count_assumption_levels_in_lbd",u"cover_optimization",b"cover_optimization",u"cp_model_max_num_presolve_operations",b"cp_model_max_num_presolve_operations",u"cp_model_postsolve_with_full_solver",b"cp_model_postsolve_with_full_solver",u"cp_model_presolve",b"cp_model_presolve",u"cp_model_probing_level",b"cp_model_probing_level",u"cp_model_use_sat_presolve",b"cp_model_use_sat_presolve",u"cut_active_count_decay",b"cut_active_count_decay",u"cut_cleanup_target",b"cut_cleanup_target",u"cut_max_active_count_value",b"cut_max_active_count_value",u"default_restart_algorithms",b"default_restart_algorithms",u"diversify_lns_params",b"diversify_lns_params",u"enumerate_all_solutions",b"enumerate_all_solutions",u"expand_automaton_constraints",b"expand_automaton_constraints",u"expand_element_constraints",b"expand_element_constraints",u"expand_table_constraints",b"expand_table_constraints",u"exploit_all_lp_solution",b"exploit_all_lp_solution",u"exploit_best_solution",b"exploit_best_solution",u"exploit_integer_lp_solution",b"exploit_integer_lp_solution",u"exploit_objective",b"exploit_objective",u"exploit_relaxation_solution",b"exploit_relaxation_solution",u"fill_tightened_domains_in_response",b"fill_tightened_domains_in_response",u"find_multiple_cores",b"find_multiple_cores",u"fp_rounding",b"fp_rounding",u"glucose_decay_increment",b"glucose_decay_increment",u"glucose_decay_increment_period",b"glucose_decay_increment_period",u"glucose_max_decay",b"glucose_max_decay",u"hint_conflict_limit",b"hint_conflict_limit",u"initial_polarity",b"initial_polarity",u"initial_variables_activity",b"initial_variables_activity",u"instantiate_all_variables",b"instantiate_all_variables",u"interleave_batch_size",b"interleave_batch_size",u"interleave_search",b"interleave_search",u"linearization_level",b"linearization_level",u"lns_focus_on_decision_variables",b"lns_focus_on_decision_variables",u"log_search_progress",b"log_search_progress",u"max_all_diff_cut_size",b"max_all_diff_cut_size",u"max_clause_activity_value",b"max_clause_activity_value",u"max_consecutive_inactive_count",b"max_consecutive_inactive_count",u"max_cut_rounds_at_level_zero",b"max_cut_rounds_at_level_zero",u"max_deterministic_time",b"max_deterministic_time",u"max_integer_rounding_scaling",b"max_integer_rounding_scaling",u"max_memory_in_mb",b"max_memory_in_mb",u"max_num_cuts",b"max_num_cuts",u"max_number_of_conflicts",b"max_number_of_conflicts",u"max_presolve_iterations",b"max_presolve_iterations",u"max_sat_assumption_order",b"max_sat_assumption_order",u"max_sat_reverse_assumption_order",b"max_sat_reverse_assumption_order",u"max_sat_stratification",b"max_sat_stratification",u"max_time_in_seconds",b"max_time_in_seconds",u"max_variable_activity_value",b"max_variable_activity_value",u"merge_at_most_one_work_limit",b"merge_at_most_one_work_limit",u"merge_no_overlap_work_limit",b"merge_no_overlap_work_limit",u"min_orthogonality_for_lp_constraints",b"min_orthogonality_for_lp_constraints",u"minimization_algorithm",b"minimization_algorithm",u"minimize_core",b"minimize_core",u"minimize_reduction_during_pb_resolution",b"minimize_reduction_during_pb_resolution",u"minimize_with_propagation_num_decisions",b"minimize_with_propagation_num_decisions",u"minimize_with_propagation_restart_period",b"minimize_with_propagation_restart_period",u"mip_check_precision",b"mip_check_precision",u"mip_max_activity_exponent",b"mip_max_activity_exponent",u"mip_max_bound",b"mip_max_bound",u"mip_var_scaling",b"mip_var_scaling",u"mip_wanted_precision",b"mip_wanted_precision",u"new_constraints_batch_size",b"new_constraints_batch_size",u"num_conflicts_before_strategy_changes",b"num_conflicts_before_strategy_changes",u"num_search_workers",b"num_search_workers",u"only_add_cuts_at_level_zero",b"only_add_cuts_at_level_zero",u"optimize_with_core",b"optimize_with_core",u"optimize_with_max_hs",b"optimize_with_max_hs",u"pb_cleanup_increment",b"pb_cleanup_increment",u"pb_cleanup_ratio",b"pb_cleanup_ratio",u"preferred_variable_order",b"preferred_variable_order",u"presolve_blocked_clause",b"presolve_blocked_clause",u"presolve_bva_threshold",b"presolve_bva_threshold",u"presolve_bve_clause_weight",b"presolve_bve_clause_weight",u"presolve_bve_threshold",b"presolve_bve_threshold",u"presolve_probing_deterministic_time_limit",b"presolve_probing_deterministic_time_limit",u"presolve_substitution_level",b"presolve_substitution_level",u"presolve_use_bva",b"presolve_use_bva",u"probing_period_at_root",b"probing_period_at_root",u"pseudo_cost_reliability_threshold",b"pseudo_cost_reliability_threshold",u"random_branches_ratio",b"random_branches_ratio",u"random_polarity_ratio",b"random_polarity_ratio",u"random_seed",b"random_seed",u"randomize_search",b"randomize_search",u"reduce_memory_usage_in_interleave_mode",b"reduce_memory_usage_in_interleave_mode",u"relative_gap_limit",b"relative_gap_limit",u"restart_algorithms",b"restart_algorithms",u"restart_dl_average_ratio",b"restart_dl_average_ratio",u"restart_lbd_average_ratio",b"restart_lbd_average_ratio",u"restart_period",b"restart_period",u"restart_running_window_size",b"restart_running_window_size",u"search_branching",b"search_branching",u"search_randomization_tolerance",b"search_randomization_tolerance",u"share_level_zero_bounds",b"share_level_zero_bounds",u"share_objective_bounds",b"share_objective_bounds",u"stop_after_first_solution",b"stop_after_first_solution",u"stop_after_presolve",b"stop_after_presolve",u"strategy_change_increase_ratio",b"strategy_change_increase_ratio",u"subsumption_during_conflict_analysis",b"subsumption_during_conflict_analysis",u"treat_binary_clauses_separately",b"treat_binary_clauses_separately",u"use_blocking_restart",b"use_blocking_restart",u"use_branching_in_lp",b"use_branching_in_lp",u"use_combined_no_overlap",b"use_combined_no_overlap",u"use_disjunctive_constraint_in_cumulative_constraint",b"use_disjunctive_constraint_in_cumulative_constraint",u"use_erwa_heuristic",b"use_erwa_heuristic",u"use_exact_lp_reason",b"use_exact_lp_reason",u"use_feasibility_pump",b"use_feasibility_pump",u"use_implied_bounds",b"use_implied_bounds",u"use_lns_only",b"use_lns_only",u"use_optimization_hints",b"use_optimization_hints",u"use_optional_variables",b"use_optional_variables",u"use_overload_checker_in_cumulative_constraint",b"use_overload_checker_in_cumulative_constraint",u"use_pb_resolution",b"use_pb_resolution",u"use_phase_saving",b"use_phase_saving",u"use_precedences_in_disjunctive_constraint",b"use_precedences_in_disjunctive_constraint",u"use_relaxation_lns",b"use_relaxation_lns",u"use_rins_lns",b"use_rins_lns",u"use_sat_inprocessing",b"use_sat_inprocessing",u"use_timetable_edge_finding_in_cumulative_constraint",b"use_timetable_edge_finding_in_cumulative_constraint",u"variable_activity_decay",b"variable_activity_decay"]) -> None: ...
type___SatParameters = SatParameters



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    NewType as typing___NewType,
    Union as typing___Union,
    cast as typing___cast,
)


builtin___bytes = bytes
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FirstSolutionStrategy(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ValueValue = typing___NewType('ValueValue', builtin___int)
    type___ValueValue = ValueValue
    Value: _Value
    class _Value(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[FirstSolutionStrategy.ValueValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSET = typing___cast(FirstSolutionStrategy.ValueValue, 0)
        AUTOMATIC = typing___cast(FirstSolutionStrategy.ValueValue, 15)
        PATH_CHEAPEST_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 3)
        PATH_MOST_CONSTRAINED_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 4)
        EVALUATOR_STRATEGY = typing___cast(FirstSolutionStrategy.ValueValue, 5)
        SAVINGS = typing___cast(FirstSolutionStrategy.ValueValue, 10)
        SWEEP = typing___cast(FirstSolutionStrategy.ValueValue, 11)
        CHRISTOFIDES = typing___cast(FirstSolutionStrategy.ValueValue, 13)
        ALL_UNPERFORMED = typing___cast(FirstSolutionStrategy.ValueValue, 6)
        BEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 7)
        PARALLEL_CHEAPEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 8)
        SEQUENTIAL_CHEAPEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 14)
        LOCAL_CHEAPEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 9)
        GLOBAL_CHEAPEST_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 1)
        LOCAL_CHEAPEST_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 2)
        FIRST_UNBOUND_MIN_VALUE = typing___cast(FirstSolutionStrategy.ValueValue, 12)
    UNSET = typing___cast(FirstSolutionStrategy.ValueValue, 0)
    AUTOMATIC = typing___cast(FirstSolutionStrategy.ValueValue, 15)
    PATH_CHEAPEST_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 3)
    PATH_MOST_CONSTRAINED_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 4)
    EVALUATOR_STRATEGY = typing___cast(FirstSolutionStrategy.ValueValue, 5)
    SAVINGS = typing___cast(FirstSolutionStrategy.ValueValue, 10)
    SWEEP = typing___cast(FirstSolutionStrategy.ValueValue, 11)
    CHRISTOFIDES = typing___cast(FirstSolutionStrategy.ValueValue, 13)
    ALL_UNPERFORMED = typing___cast(FirstSolutionStrategy.ValueValue, 6)
    BEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 7)
    PARALLEL_CHEAPEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 8)
    SEQUENTIAL_CHEAPEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 14)
    LOCAL_CHEAPEST_INSERTION = typing___cast(FirstSolutionStrategy.ValueValue, 9)
    GLOBAL_CHEAPEST_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 1)
    LOCAL_CHEAPEST_ARC = typing___cast(FirstSolutionStrategy.ValueValue, 2)
    FIRST_UNBOUND_MIN_VALUE = typing___cast(FirstSolutionStrategy.ValueValue, 12)
    type___Value = Value


    def __init__(self,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> FirstSolutionStrategy: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> FirstSolutionStrategy: ...
type___FirstSolutionStrategy = FirstSolutionStrategy

class LocalSearchMetaheuristic(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ValueValue = typing___NewType('ValueValue', builtin___int)
    type___ValueValue = ValueValue
    Value: _Value
    class _Value(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[LocalSearchMetaheuristic.ValueValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSET = typing___cast(LocalSearchMetaheuristic.ValueValue, 0)
        AUTOMATIC = typing___cast(LocalSearchMetaheuristic.ValueValue, 6)
        GREEDY_DESCENT = typing___cast(LocalSearchMetaheuristic.ValueValue, 1)
        GUIDED_LOCAL_SEARCH = typing___cast(LocalSearchMetaheuristic.ValueValue, 2)
        SIMULATED_ANNEALING = typing___cast(LocalSearchMetaheuristic.ValueValue, 3)
        TABU_SEARCH = typing___cast(LocalSearchMetaheuristic.ValueValue, 4)
        GENERIC_TABU_SEARCH = typing___cast(LocalSearchMetaheuristic.ValueValue, 5)
    UNSET = typing___cast(LocalSearchMetaheuristic.ValueValue, 0)
    AUTOMATIC = typing___cast(LocalSearchMetaheuristic.ValueValue, 6)
    GREEDY_DESCENT = typing___cast(LocalSearchMetaheuristic.ValueValue, 1)
    GUIDED_LOCAL_SEARCH = typing___cast(LocalSearchMetaheuristic.ValueValue, 2)
    SIMULATED_ANNEALING = typing___cast(LocalSearchMetaheuristic.ValueValue, 3)
    TABU_SEARCH = typing___cast(LocalSearchMetaheuristic.ValueValue, 4)
    GENERIC_TABU_SEARCH = typing___cast(LocalSearchMetaheuristic.ValueValue, 5)
    type___Value = Value


    def __init__(self,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LocalSearchMetaheuristic: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LocalSearchMetaheuristic: ...
type___LocalSearchMetaheuristic = LocalSearchMetaheuristic



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConstraintSolverParameters(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TrailCompressionValue = typing___NewType('TrailCompressionValue', builtin___int)
    type___TrailCompressionValue = TrailCompressionValue
    TrailCompression: _TrailCompression
    class _TrailCompression(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[ConstraintSolverParameters.TrailCompressionValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        NO_COMPRESSION = typing___cast(ConstraintSolverParameters.TrailCompressionValue, 0)
        COMPRESS_WITH_ZLIB = typing___cast(ConstraintSolverParameters.TrailCompressionValue, 1)
    NO_COMPRESSION = typing___cast(ConstraintSolverParameters.TrailCompressionValue, 0)
    COMPRESS_WITH_ZLIB = typing___cast(ConstraintSolverParameters.TrailCompressionValue, 1)
    type___TrailCompression = TrailCompression

    compress_trail: type___ConstraintSolverParameters.TrailCompressionValue = ...
    trail_block_size: builtin___int = ...
    array_split_size: builtin___int = ...
    store_names: builtin___bool = ...
    name_cast_variables: builtin___bool = ...
    name_all_variables: builtin___bool = ...
    profile_propagation: builtin___bool = ...
    profile_file: typing___Text = ...
    profile_local_search: builtin___bool = ...
    print_local_search_profile: builtin___bool = ...
    trace_propagation: builtin___bool = ...
    trace_search: builtin___bool = ...
    print_model: builtin___bool = ...
    print_model_stats: builtin___bool = ...
    print_added_constraints: builtin___bool = ...
    disable_solve: builtin___bool = ...
    use_small_table: builtin___bool = ...
    use_cumulative_edge_finder: builtin___bool = ...
    use_cumulative_time_table: builtin___bool = ...
    use_cumulative_time_table_sync: builtin___bool = ...
    use_sequence_high_demand_tasks: builtin___bool = ...
    use_all_possible_disjunctions: builtin___bool = ...
    max_edge_finder_size: builtin___int = ...
    diffn_use_cumulative: builtin___bool = ...
    use_element_rmq: builtin___bool = ...
    skip_locally_optimal_paths: builtin___bool = ...
    check_solution_period: builtin___int = ...

    def __init__(self,
        *,
        compress_trail : typing___Optional[type___ConstraintSolverParameters.TrailCompressionValue] = None,
        trail_block_size : typing___Optional[builtin___int] = None,
        array_split_size : typing___Optional[builtin___int] = None,
        store_names : typing___Optional[builtin___bool] = None,
        name_cast_variables : typing___Optional[builtin___bool] = None,
        name_all_variables : typing___Optional[builtin___bool] = None,
        profile_propagation : typing___Optional[builtin___bool] = None,
        profile_file : typing___Optional[typing___Text] = None,
        profile_local_search : typing___Optional[builtin___bool] = None,
        print_local_search_profile : typing___Optional[builtin___bool] = None,
        trace_propagation : typing___Optional[builtin___bool] = None,
        trace_search : typing___Optional[builtin___bool] = None,
        print_model : typing___Optional[builtin___bool] = None,
        print_model_stats : typing___Optional[builtin___bool] = None,
        print_added_constraints : typing___Optional[builtin___bool] = None,
        disable_solve : typing___Optional[builtin___bool] = None,
        use_small_table : typing___Optional[builtin___bool] = None,
        use_cumulative_edge_finder : typing___Optional[builtin___bool] = None,
        use_cumulative_time_table : typing___Optional[builtin___bool] = None,
        use_cumulative_time_table_sync : typing___Optional[builtin___bool] = None,
        use_sequence_high_demand_tasks : typing___Optional[builtin___bool] = None,
        use_all_possible_disjunctions : typing___Optional[builtin___bool] = None,
        max_edge_finder_size : typing___Optional[builtin___int] = None,
        diffn_use_cumulative : typing___Optional[builtin___bool] = None,
        use_element_rmq : typing___Optional[builtin___bool] = None,
        skip_locally_optimal_paths : typing___Optional[builtin___bool] = None,
        check_solution_period : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> ConstraintSolverParameters: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> ConstraintSolverParameters: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"array_split_size",b"array_split_size",u"check_solution_period",b"check_solution_period",u"compress_trail",b"compress_trail",u"diffn_use_cumulative",b"diffn_use_cumulative",u"disable_solve",b"disable_solve",u"max_edge_finder_size",b"max_edge_finder_size",u"name_all_variables",b"name_all_variables",u"name_cast_variables",b"name_cast_variables",u"print_added_constraints",b"print_added_constraints",u"print_local_search_profile",b"print_local_search_profile",u"print_model",b"print_model",u"print_model_stats",b"print_model_stats",u"profile_file",b"profile_file",u"profile_local_search",b"profile_local_search",u"profile_propagation",b"profile_propagation",u"skip_locally_optimal_paths",b"skip_locally_optimal_paths",u"store_names",b"store_names",u"trace_propagation",b"trace_propagation",u"trace_search",b"trace_search",u"trail_block_size",b"trail_block_size",u"use_all_possible_disjunctions",b"use_all_possible_disjunctions",u"use_cumulative_edge_finder",b"use_cumulative_edge_finder",u"use_cumulative_time_table",b"use_cumulative_time_table",u"use_cumulative_time_table_sync",b"use_cumulative_time_table_sync",u"use_element_rmq",b"use_element_rmq",u"use_sequence_high_demand_tasks",b"use_sequence_high_demand_tasks",u"use_small_table",b"use_small_table"]) -> None: ...
type___ConstraintSolverParameters = ConstraintSolverParameters



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    NewType as typing___NewType,
    cast as typing___cast,
)


builtin___int = int


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

OptionalBooleanValue = typing___NewType('OptionalBooleanValue', builtin___int)
type___OptionalBooleanValue = OptionalBooleanValue
OptionalBoolean: _OptionalBoolean
class _OptionalBoolean(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[OptionalBooleanValue]):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    BOOL_UNSPECIFIED = typing___cast(OptionalBooleanValue, 0)
    BOOL_FALSE = typing___cast(OptionalBooleanValue, 2)
    BOOL_TRUE = typing___cast(OptionalBooleanValue, 3)
BOOL_UNSPECIFIED = typing___cast(OptionalBooleanValue, 0)
BOOL_FALSE = typing___cast(OptionalBooleanValue, 2)
BOOL_TRUE = typing___cast(OptionalBooleanValue, 3)
type___OptionalBoolean = OptionalBoolean



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class RegularLimitParameters(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    time: builtin___int = ...
    branches: builtin___int = ...
    failures: builtin___int = ...
    solutions: builtin___int = ...
    smart_time_check: builtin___bool = ...
    cumulative: builtin___bool = ...

    def __init__(self,
        *,
        time : typing___Optional[builtin___int] = None,
        branches : typing___Optional[builtin___int] = None,
        failures : typing___Optional[builtin___int] = None,
        solutions : typing___Optional[builtin___int] = None,
        smart_time_check : typing___Optional[builtin___bool] = None,
        cumulative : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> RegularLimitParameters: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> RegularLimitParameters: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"branches",b"branches",u"cumulative",b"cumulative",u"failures",b"failures",u"smart_time_check",b"smart_time_check",u"solutions",b"solutions",u"time",b"time"]) -> None: ...
type___RegularLimitParameters = RegularLimitParameters



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)

from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from ortools.util.optional_boolean_pb2 import (
    OptionalBooleanValue as ortools___util___optional_boolean_pb2___OptionalBooleanValue,
)

from typing import (
    Iterable as typing___Iterable,
    Mapping as typing___Mapping,
    MutableMapping as typing___MutableMapping,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

MPSolverResponseStatusValue = typing___NewType('MPSolverResponseStatusValue', builtin___int)
type___MPSolverResponseStatusValue = MPSolverResponseStatusValue
MPSolverResponseStatus: _MPSolverResponseStatus
class _MPSolverResponseStatus(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[MPSolverResponseStatusValue]):
    DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
    MPSOLVER_OPTIMAL = typing___cast(MPSolverResponseStatusValue, 0)
    MPSOLVER_FEASIBLE = typing___cast(MPSolverResponseStatusValue, 1)
    MPSOLVER_INFEASIBLE = typing___cast(MPSolverResponseStatusValue, 2)
    MPSOLVER_UNBOUNDED = typing___cast(MPSolverResponseStatusValue, 3)
    MPSOLVER_ABNORMAL = typing___cast(MPSolverResponseStatusValue, 4)
    MPSOLVER_NOT_SOLVED = typing___cast(MPSolverResponseStatusValue, 6)
    MPSOLVER_MODEL_IS_VALID = typing___cast(MPSolverResponseStatusValue, 97)
    MPSOLVER_UNKNOWN_STATUS = typing___cast(MPSolverResponseStatusValue, 99)
    MPSOLVER_MODEL_INVALID = typing___cast(MPSolverResponseStatusValue, 5)
    MPSOLVER_MODEL_INVALID_SOLUTION_HINT = typing___cast(MPSolverResponseStatusValue, 84)
    MPSOLVER_MODEL_INVALID_SOLVER_PARAMETERS = typing___cast(MPSolverResponseStatusValue, 85)
    MPSOLVER_SOLVER_TYPE_UNAVAILABLE = typing___cast(MPSolverResponseStatusValue, 7)
MPSOLVER_OPTIMAL = typing___cast(MPSolverResponseStatusValue, 0)
MPSOLVER_FEASIBLE = typing___cast(MPSolverResponseStatusValue, 1)
MPSOLVER_INFEASIBLE = typing___cast(MPSolverResponseStatusValue, 2)
MPSOLVER_UNBOUNDED = typing___cast(MPSolverResponseStatusValue, 3)
MPSOLVER_ABNORMAL = typing___cast(MPSolverResponseStatusValue, 4)
MPSOLVER_NOT_SOLVED = typing___cast(MPSolverResponseStatusValue, 6)
MPSOLVER_MODEL_IS_VALID = typing___cast(MPSolverResponseStatusValue, 97)
MPSOLVER_UNKNOWN_STATUS = typing___cast(MPSolverResponseStatusValue, 99)
MPSOLVER_MODEL_INVALID = typing___cast(MPSolverResponseStatusValue, 5)
MPSOLVER_MODEL_INVALID_SOLUTION_HINT = typing___cast(MPSolverResponseStatusValue, 84)
MPSOLVER_MODEL_INVALID_SOLVER_PARAMETERS = typing___cast(MPSolverResponseStatusValue, 85)
MPSOLVER_SOLVER_TYPE_UNAVAILABLE = typing___cast(MPSolverResponseStatusValue, 7)
type___MPSolverResponseStatus = MPSolverResponseStatus

class MPVariableProto(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    lower_bound: builtin___float = ...
    upper_bound: builtin___float = ...
    objective_coefficient: builtin___float = ...
    is_integer: builtin___bool = ...
    name: typing___Text = ...
    branching_priority: builtin___int = ...

    def __init__(self,
        *,
        lower_bound : typing___Optional[builtin___float] = None,
        upper_bound : typing___Optional[builtin___float] = None,
        objective_coefficient : typing___Optional[builtin___float] = None,
        is_integer : typing___Optional[builtin___bool] = None,
        name : typing___Optional[typing___Text] = None,
        branching_priority : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPVariableProto: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPVariableProto: ...
    def HasField(self, field_name: typing_extensions___Literal[u"branching_priority",b"branching_priority",u"is_integer",b"is_integer",u"lower_bound",b"lower_bound",u"name",b"name",u"objective_coefficient",b"objective_coefficient",u"upper_bound",b"upper_bound"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"branching_priority",b"branching_priority",u"is_integer",b"is_integer",u"lower_bound",b"lower_bound",u"name",b"name",u"objective_coefficient",b"objective_coefficient",u"upper_bound",b"upper_bound"]) -> None: ...
type___MPVariableProto = MPVariableProto

class MPConstraintProto(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    coefficient: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...
    lower_bound: builtin___float = ...
    upper_bound: builtin___float = ...
    name: typing___Text = ...
    is_lazy: builtin___bool = ...

    def __init__(self,
        *,
        var_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        coefficient : typing___Optional[typing___Iterable[builtin___float]] = None,
        lower_bound : typing___Optional[builtin___float] = None,
        upper_bound : typing___Optional[builtin___float] = None,
        name : typing___Optional[typing___Text] = None,
        is_lazy : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPConstraintProto: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPConstraintProto: ...
    def HasField(self, field_name: typing_extensions___Literal[u"is_lazy",b"is_lazy",u"lower_bound",b"lower_bound",u"name",b"name",u"upper_bound",b"upper_bound"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"coefficient",b"coefficient",u"is_lazy",b"is_lazy",u"lower_bound",b"lower_bound",u"name",b"name",u"upper_bound",b"upper_bound",u"var_index",b"var_index"]) -> None: ...
type___MPConstraintProto = MPConstraintProto

class MPGeneralConstraintProto(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    name: typing___Text = ...

    @property
    def indicator_constraint(self) -> type___MPIndicatorConstraint: ...

    @property
    def sos_constraint(self) -> type___MPSosConstraint: ...

    @property
    def quadratic_constraint(self) -> type___MPQuadraticConstraint: ...

    @property
    def abs_constraint(self) -> type___MPAbsConstraint: ...

    @property
    def and_constraint(self) -> type___MPArrayConstraint: ...

    @property
    def or_constraint(self) -> type___MPArrayConstraint: ...

    @property
    def min_constraint(self) -> type___MPArrayWithConstantConstraint: ...

    @property
    def max_constraint(self) -> type___MPArrayWithConstantConstraint: ...

    def __init__(self,
        *,
        name : typing___Optional[typing___Text] = None,
        indicator_constraint : typing___Optional[type___MPIndicatorConstraint] = None,
        sos_constraint : typing___Optional[type___MPSosConstraint] = None,
        quadratic_constraint : typing___Optional[type___MPQuadraticConstraint] = None,
        abs_constraint : typing___Optional[type___MPAbsConstraint] = None,
        and_constraint : typing___Optional[type___MPArrayConstraint] = None,
        or_constraint : typing___Optional[type___MPArrayConstraint] = None,
        min_constraint : typing___Optional[type___MPArrayWithConstantConstraint] = None,
        max_constraint : typing___Optional[type___MPArrayWithConstantConstraint] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPGeneralConstraintProto: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPGeneralConstraintProto: ...
    def HasField(self, field_name: typing_extensions___Literal[u"abs_constraint",b"abs_constraint",u"and_constraint",b"and_constraint",u"general_constraint",b"general_constraint",u"indicator_constraint",b"indicator_constraint",u"max_constraint",b"max_constraint",u"min_constraint",b"min_constraint",u"name",b"name",u"or_constraint",b"or_constraint",u"quadratic_constraint",b"quadratic_constraint",u"sos_constraint",b"sos_constraint"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"abs_constraint",b"abs_constraint",u"and_constraint",b"and_constraint",u"general_constraint",b"general_constraint",u"indicator_constraint",b"indicator_constraint",u"max_constraint",b"max_constraint",u"min_constraint",b"min_constraint",u"name",b"name",u"or_constraint",b"or_constraint",u"quadratic_constraint",b"quadratic_constraint",u"sos_constraint",b"sos_constraint"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"general_constraint",b"general_constraint"]) -> typing_extensions___Literal["indicator_constraint","sos_constraint","quadratic_constraint","abs_constraint","and_constraint","or_constraint","min_constraint","max_constraint"]: ...
type___MPGeneralConstraintProto = MPGeneralConstraintProto

class MPIndicatorConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: builtin___int = ...
    var_value: builtin___int = ...

    @property
    def constraint(self) -> type___MPConstraintProto: ...

    def __init__(self,
        *,
        var_index : typing___Optional[builtin___int] = None,
        var_value : typing___Optional[builtin___int] = None,
        constraint : typing___Optional[type___MPConstraintProto] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPIndicatorConstraint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPIndicatorConstraint: ...
    def HasField(self, field_name: typing_extensions___Literal[u"constraint",b"constraint",u"var_index",b"var_index",u"var_value",b"var_value"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"constraint",b"constraint",u"var_index",b"var_index",u"var_value",b"var_value"]) -> None: ...
type___MPIndicatorConstraint = MPIndicatorConstraint

class MPSosConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TypeValue = typing___NewType('TypeValue', builtin___int)
    type___TypeValue = TypeValue
    Type: _Type
    class _Type(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[MPSosConstraint.TypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        SOS1_DEFAULT = typing___cast(MPSosConstraint.TypeValue, 0)
        SOS2 = typing___cast(MPSosConstraint.TypeValue, 1)
    SOS1_DEFAULT = typing___cast(MPSosConstraint.TypeValue, 0)
    SOS2 = typing___cast(MPSosConstraint.TypeValue, 1)
    type___Type = Type

    type: type___MPSosConstraint.TypeValue = ...
    var_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    weight: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        type : typing___Optional[type___MPSosConstraint.TypeValue] = None,
        var_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        weight : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPSosConstraint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPSosConstraint: ...
    def HasField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type",u"var_index",b"var_index",u"weight",b"weight"]) -> None: ...
type___MPSosConstraint = MPSosConstraint

class MPQuadraticConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    coefficient: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...
    qvar1_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    qvar2_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    qcoefficient: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...
    lower_bound: builtin___float = ...
    upper_bound: builtin___float = ...

    def __init__(self,
        *,
        var_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        coefficient : typing___Optional[typing___Iterable[builtin___float]] = None,
        qvar1_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        qvar2_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        qcoefficient : typing___Optional[typing___Iterable[builtin___float]] = None,
        lower_bound : typing___Optional[builtin___float] = None,
        upper_bound : typing___Optional[builtin___float] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPQuadraticConstraint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPQuadraticConstraint: ...
    def HasField(self, field_name: typing_extensions___Literal[u"lower_bound",b"lower_bound",u"upper_bound",b"upper_bound"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"coefficient",b"coefficient",u"lower_bound",b"lower_bound",u"qcoefficient",b"qcoefficient",u"qvar1_index",b"qvar1_index",u"qvar2_index",b"qvar2_index",u"upper_bound",b"upper_bound",u"var_index",b"var_index"]) -> None: ...
type___MPQuadraticConstraint = MPQuadraticConstraint

class MPAbsConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: builtin___int = ...
    resultant_var_index: builtin___int = ...

    def __init__(self,
        *,
        var_index : typing___Optional[builtin___int] = None,
        resultant_var_index : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPAbsConstraint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPAbsConstraint: ...
    def HasField(self, field_name: typing_extensions___Literal[u"resultant_var_index",b"resultant_var_index",u"var_index",b"var_index"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"resultant_var_index",b"resultant_var_index",u"var_index",b"var_index"]) -> None: ...
type___MPAbsConstraint = MPAbsConstraint

class MPArrayConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    resultant_var_index: builtin___int = ...

    def __init__(self,
        *,
        var_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        resultant_var_index : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPArrayConstraint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPArrayConstraint: ...
    def HasField(self, field_name: typing_extensions___Literal[u"resultant_var_index",b"resultant_var_index"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"resultant_var_index",b"resultant_var_index",u"var_index",b"var_index"]) -> None: ...
type___MPArrayConstraint = MPArrayConstraint

class MPArrayWithConstantConstraint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    constant: builtin___float = ...
    resultant_var_index: builtin___int = ...

    def __init__(self,
        *,
        var_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        constant : typing___Optional[builtin___float] = None,
        resultant_var_index : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPArrayWithConstantConstraint: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPArrayWithConstantConstraint: ...
    def HasField(self, field_name: typing_extensions___Literal[u"constant",b"constant",u"resultant_var_index",b"resultant_var_index"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"constant",b"constant",u"resultant_var_index",b"resultant_var_index",u"var_index",b"var_index"]) -> None: ...
type___MPArrayWithConstantConstraint = MPArrayWithConstantConstraint

class MPQuadraticObjective(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    qvar1_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    qvar2_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    coefficient: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        qvar1_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        qvar2_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        coefficient : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPQuadraticObjective: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPQuadraticObjective: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"coefficient",b"coefficient",u"qvar1_index",b"qvar1_index",u"qvar2_index",b"qvar2_index"]) -> None: ...
type___MPQuadraticObjective = MPQuadraticObjective

class PartialVariableAssignment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    var_index: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___int] = ...
    var_value: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        var_index : typing___Optional[typing___Iterable[builtin___int]] = None,
        var_value : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> PartialVariableAssignment: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> PartialVariableAssignment: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"var_index",b"var_index",u"var_value",b"var_value"]) -> None: ...
type___PartialVariableAssignment = PartialVariableAssignment

class MPModelProto(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    maximize: builtin___bool = ...
    objective_offset: builtin___float = ...
    name: typing___Text = ...

    @property
    def variable(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___MPVariableProto]: ...

    @property
    def constraint(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___MPConstraintProto]: ...

    @property
    def general_constraint(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[type___MPGeneralConstraintProto]: ...

    @property
    def quadratic_objective(self) -> type___MPQuadraticObjective: ...

    @property
    def solution_hint(self) -> type___PartialVariableAssignment: ...

    def __init__(self,
        *,
        variable : typing___Optional[typing___Iterable[type___MPVariableProto]] = None,
        constraint : typing___Optional[typing___Iterable[type___MPConstraintProto]] = None,
        general_constraint : typing___Optional[typing___Iterable[type___MPGeneralConstraintProto]] = None,
        maximize : typing___Optional[builtin___bool] = None,
        objective_offset : typing___Optional[builtin___float] = None,
        quadratic_objective : typing___Optional[type___MPQuadraticObjective] = None,
        name : typing___Optional[typing___Text] = None,
        solution_hint : typing___Optional[type___PartialVariableAssignment] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPModelProto: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPModelProto: ...
    def HasField(self, field_name: typing_extensions___Literal[u"maximize",b"maximize",u"name",b"name",u"objective_offset",b"objective_offset",u"quadratic_objective",b"quadratic_objective",u"solution_hint",b"solution_hint"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"constraint",b"constraint",u"general_constraint",b"general_constraint",u"maximize",b"maximize",u"name",b"name",u"objective_offset",b"objective_offset",u"quadratic_objective",b"quadratic_objective",u"solution_hint",b"solution_hint",u"variable",b"variable"]) -> None: ...
type___MPModelProto = MPModelProto

class OptionalDouble(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    value: builtin___float = ...

    def __init__(self,
        *,
        value : typing___Optional[builtin___float] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> OptionalDouble: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> OptionalDouble: ...
    def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...
type___OptionalDouble = OptionalDouble

class MPSolverCommonParameters(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LPAlgorithmValuesValue = typing___NewType('LPAlgorithmValuesValue', builtin___int)
    type___LPAlgorithmValuesValue = LPAlgorithmValuesValue
    LPAlgorithmValues: _LPAlgorithmValues
    class _LPAlgorithmValues(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[MPSolverCommonParameters.LPAlgorithmValuesValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        LP_ALGO_UNSPECIFIED = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 0)
        LP_ALGO_DUAL = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 1)
        LP_ALGO_PRIMAL = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 2)
        LP_ALGO_BARRIER = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 3)
    LP_ALGO_UNSPECIFIED = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 0)
    LP_ALGO_DUAL = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 1)
    LP_ALGO_PRIMAL = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 2)
    LP_ALGO_BARRIER = typing___cast(MPSolverCommonParameters.LPAlgorithmValuesValue, 3)
    type___LPAlgorithmValues = LPAlgorithmValues

    lp_algorithm: type___MPSolverCommonParameters.LPAlgorithmValuesValue = ...
    presolve: ortools___util___optional_boolean_pb2___OptionalBooleanValue = ...
    scaling: ortools___util___optional_boolean_pb2___OptionalBooleanValue = ...

    @property
    def relative_mip_gap(self) -> type___OptionalDouble: ...

    @property
    def primal_tolerance(self) -> type___OptionalDouble: ...

    @property
    def dual_tolerance(self) -> type___OptionalDouble: ...

    def __init__(self,
        *,
        relative_mip_gap : typing___Optional[type___OptionalDouble] = None,
        primal_tolerance : typing___Optional[type___OptionalDouble] = None,
        dual_tolerance : typing___Optional[type___OptionalDouble] = None,
        lp_algorithm : typing___Optional[type___MPSolverCommonParameters.LPAlgorithmValuesValue] = None,
        presolve : typing___Optional[ortools___util___optional_boolean_pb2___OptionalBooleanValue] = None,
        scaling : typing___Optional[ortools___util___optional_boolean_pb2___OptionalBooleanValue] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPSolverCommonParameters: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPSolverCommonParameters: ...
    def HasField(self, field_name: typing_extensions___Literal[u"dual_tolerance",b"dual_tolerance",u"lp_algorithm",b"lp_algorithm",u"presolve",b"presolve",u"primal_tolerance",b"primal_tolerance",u"relative_mip_gap",b"relative_mip_gap",u"scaling",b"scaling"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"dual_tolerance",b"dual_tolerance",u"lp_algorithm",b"lp_algorithm",u"presolve",b"presolve",u"primal_tolerance",b"primal_tolerance",u"relative_mip_gap",b"relative_mip_gap",u"scaling",b"scaling"]) -> None: ...
type___MPSolverCommonParameters = MPSolverCommonParameters

class MPModelDeltaProto(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class VariableOverridesEntry(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        key: builtin___int = ...

        @property
        def value(self) -> type___MPVariableProto: ...

        def __init__(self,
            *,
            key : typing___Optional[builtin___int] = None,
            value : typing___Optional[type___MPVariableProto] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> MPModelDeltaProto.VariableOverridesEntry: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPModelDeltaProto.VariableOverridesEntry: ...
        def HasField(self, field_name: typing_extensions___Literal[u"key",b"key",u"value",b"value"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"key",b"key",u"value",b"value"]) -> None: ...
    type___VariableOverridesEntry = VariableOverridesEntry

    class ConstraintOverridesEntry(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        key: builtin___int = ...

        @property
        def value(self) -> type___MPConstraintProto: ...

        def __init__(self,
            *,
            key : typing___Optional[builtin___int] = None,
            value : typing___Optional[type___MPConstraintProto] = None,
            ) -> None: ...
        if sys.version_info >= (3,):
            @classmethod
            def FromString(cls, s: builtin___bytes) -> MPModelDeltaProto.ConstraintOverridesEntry: ...
        else:
            @classmethod
            def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPModelDeltaProto.ConstraintOverridesEntry: ...
        def HasField(self, field_name: typing_extensions___Literal[u"key",b"key",u"value",b"value"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"key",b"key",u"value",b"value"]) -> None: ...
    type___ConstraintOverridesEntry = ConstraintOverridesEntry

    baseline_model_file_path: typing___Text = ...

    @property
    def variable_overrides(self) -> typing___MutableMapping[builtin___int, type___MPVariableProto]: ...

    @property
    def constraint_overrides(self) -> typing___MutableMapping[builtin___int, type___MPConstraintProto]: ...

    def __init__(self,
        *,
        baseline_model_file_path : typing___Optional[typing___Text] = None,
        variable_overrides : typing___Optional[typing___Mapping[builtin___int, type___MPVariableProto]] = None,
        constraint_overrides : typing___Optional[typing___Mapping[builtin___int, type___MPConstraintProto]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPModelDeltaProto: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPModelDeltaProto: ...
    def HasField(self, field_name: typing_extensions___Literal[u"baseline_model_file_path",b"baseline_model_file_path"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"baseline_model_file_path",b"baseline_model_file_path",u"constraint_overrides",b"constraint_overrides",u"variable_overrides",b"variable_overrides"]) -> None: ...
type___MPModelDeltaProto = MPModelDeltaProto

class MPModelRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SolverTypeValue = typing___NewType('SolverTypeValue', builtin___int)
    type___SolverTypeValue = SolverTypeValue
    SolverType: _SolverType
    class _SolverType(google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[MPModelRequest.SolverTypeValue]):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        GLOP_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 2)
        CLP_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 0)
        GLPK_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 1)
        GUROBI_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 6)
        XPRESS_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 101)
        CPLEX_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 10)
        SCIP_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 3)
        GLPK_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 4)
        CBC_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 5)
        GUROBI_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 7)
        XPRESS_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 102)
        CPLEX_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 11)
        BOP_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 12)
        SAT_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 14)
        KNAPSACK_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 13)
    GLOP_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 2)
    CLP_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 0)
    GLPK_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 1)
    GUROBI_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 6)
    XPRESS_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 101)
    CPLEX_LINEAR_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 10)
    SCIP_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 3)
    GLPK_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 4)
    CBC_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 5)
    GUROBI_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 7)
    XPRESS_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 102)
    CPLEX_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 11)
    BOP_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 12)
    SAT_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 14)
    KNAPSACK_MIXED_INTEGER_PROGRAMMING = typing___cast(MPModelRequest.SolverTypeValue, 13)
    type___SolverType = SolverType

    solver_type: type___MPModelRequest.SolverTypeValue = ...
    solver_time_limit_seconds: builtin___float = ...
    enable_internal_solver_output: builtin___bool = ...
    solver_specific_parameters: typing___Text = ...

    @property
    def model(self) -> type___MPModelProto: ...

    @property
    def model_delta(self) -> type___MPModelDeltaProto: ...

    def __init__(self,
        *,
        model : typing___Optional[type___MPModelProto] = None,
        solver_type : typing___Optional[type___MPModelRequest.SolverTypeValue] = None,
        solver_time_limit_seconds : typing___Optional[builtin___float] = None,
        enable_internal_solver_output : typing___Optional[builtin___bool] = None,
        solver_specific_parameters : typing___Optional[typing___Text] = None,
        model_delta : typing___Optional[type___MPModelDeltaProto] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPModelRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPModelRequest: ...
    def HasField(self, field_name: typing_extensions___Literal[u"enable_internal_solver_output",b"enable_internal_solver_output",u"model",b"model",u"model_delta",b"model_delta",u"solver_specific_parameters",b"solver_specific_parameters",u"solver_time_limit_seconds",b"solver_time_limit_seconds",u"solver_type",b"solver_type"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"enable_internal_solver_output",b"enable_internal_solver_output",u"model",b"model",u"model_delta",b"model_delta",u"solver_specific_parameters",b"solver_specific_parameters",u"solver_time_limit_seconds",b"solver_time_limit_seconds",u"solver_type",b"solver_type"]) -> None: ...
type___MPModelRequest = MPModelRequest

class MPSolutionResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    status: type___MPSolverResponseStatusValue = ...
    status_str: typing___Text = ...
    objective_value: builtin___float = ...
    best_objective_bound: builtin___float = ...
    variable_value: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...
    dual_value: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...
    reduced_cost: google___protobuf___internal___containers___RepeatedScalarFieldContainer[builtin___float] = ...

    def __init__(self,
        *,
        status : typing___Optional[type___MPSolverResponseStatusValue] = None,
        status_str : typing___Optional[typing___Text] = None,
        objective_value : typing___Optional[builtin___float] = None,
        best_objective_bound : typing___Optional[builtin___float] = None,
        variable_value : typing___Optional[typing___Iterable[builtin___float]] = None,
        dual_value : typing___Optional[typing___Iterable[builtin___float]] = None,
        reduced_cost : typing___Optional[typing___Iterable[builtin___float]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> MPSolutionResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> MPSolutionResponse: ...
    def HasField(self, field_name: typing_extensions___Literal[u"best_objective_bound",b"best_objective_bound",u"objective_value",b"objective_value",u"status",b"status",u"status_str",b"status_str"]) -> builtin___bool: ...
    def ClearField(self, field_name: typing_extensions___Literal[u"best_objective_bound",b"best_objective_bound",u"dual_value",b"dual_value",u"objective_value",b"objective_value",u"reduced_cost",b"reduced_cost",u"status",b"status",u"status_str",b"status_str",u"variable_value",b"variable_value"]) -> None: ...
type___MPSolutionResponse = MPSolutionResponse



from setuptools import setup
import os

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


def find_stubs(package):
    stubs = []
    for root, dirs, files in os.walk(package):
        for file in files:
            path = os.path.join(root, file).replace(package + os.sep, '', 1)
            stubs.append(path)
    return {package: stubs}

# twine upload --skip-existing --repository pypi dist/*
setup(
    name='ortools-stubs',
    maintainer="Xiang Chen",
    maintainer_email="xiangchenchen96@gmail.com",
    description="PEP 561 type stubs for Google OR-Tools",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/stradivari96/ortools-stubs",
    license='MIT',
    version="7.7.0",
    packages=['ortools-stubs'],
    package_data=find_stubs('ortools-stubs'),
)
